@@ -1,7 +1,6 @@
 #ifndef INCLUDE_RUBY_CONFIG_H
 #define INCLUDE_RUBY_CONFIG_H 1
 /* confdefs.h */
-#define CANONICALIZATION_FOR_MATHN 1
 #define STDC_HEADERS 1
 #define HAVE_SYS_TYPES_H 1
 #define HAVE_SYS_STAT_H 1
@@ -17,10 +16,9 @@
 #define _GNU_SOURCE 1
 #define _POSIX_PTHREAD_SEMANTICS 1
 #define _TANDEM_SOURCE 1
-#define HAVE_INFINITY 1
-#define HAVE_NAN 1
 #define RUBY_SYMBOL_EXPORT_BEGIN _Pragma("GCC visibility push(default)")
 #define RUBY_SYMBOL_EXPORT_END _Pragma("GCC visibility pop")
+#define HAVE_STMT_AND_DECL_IN_EXPR 1
 #define HAVE_DIRENT_H 1
 #define HAVE__BOOL 1
 #define HAVE_STDBOOL_H 1
@@ -34,6 +32,7 @@
 #define HAVE_LIMITS_H 1
 #define HAVE_LOCALE_H 1
 #define HAVE_PWD_H 1
+#define HAVE_STDALIGN_H 1
 #define HAVE_SYS_FCNTL_H 1
 #define HAVE_SYS_FILE_H 1
 #define HAVE_SYS_IOCTL_H 1
@@ -67,46 +66,55 @@
 #define PACKED_STRUCT(x) x __attribute__((packed))
 #define USE_UNALIGNED_MEMBER_ACCESS 1
 #define PRI_LL_PREFIX "ll"
+#define HAVE_PID_T 1
 #define rb_pid_t pid_t
 #define SIGNEDNESS_OF_PID_T -1
 #define PIDT2NUM(v) INT2NUM(v)
 #define NUM2PIDT(v) NUM2INT(v)
 #define PRI_PIDT_PREFIX PRI_INT_PREFIX
+#define HAVE_UID_T 1
 #define rb_uid_t uid_t
 #define SIGNEDNESS_OF_UID_T +1
 #define UIDT2NUM(v) UINT2NUM(v)
 #define NUM2UIDT(v) NUM2UINT(v)
 #define PRI_UIDT_PREFIX PRI_INT_PREFIX
+#define HAVE_GID_T 1
 #define rb_gid_t gid_t
 #define SIGNEDNESS_OF_GID_T +1
 #define GIDT2NUM(v) UINT2NUM(v)
 #define NUM2GIDT(v) NUM2UINT(v)
 #define PRI_GIDT_PREFIX PRI_INT_PREFIX
+#define HAVE_TIME_T 1
 #define rb_time_t time_t
 #define SIGNEDNESS_OF_TIME_T -1
 #define TIMET2NUM(v) LL2NUM(v)
 #define NUM2TIMET(v) NUM2LL(v)
 #define PRI_TIMET_PREFIX PRI_LL_PREFIX
+#define HAVE_DEV_T 1
 #define rb_dev_t dev_t
 #define SIGNEDNESS_OF_DEV_T -1
 #define DEVT2NUM(v) INT2NUM(v)
 #define NUM2DEVT(v) NUM2INT(v)
 #define PRI_DEVT_PREFIX PRI_INT_PREFIX
+#define HAVE_MODE_T 1
 #define rb_mode_t mode_t
 #define SIGNEDNESS_OF_MODE_T +1
 #define MODET2NUM(v) UINT2NUM(v)
 #define NUM2MODET(v) NUM2UINT(v)
 #define PRI_MODET_PREFIX PRI_INT_PREFIX
+#define HAVE_RLIM_T 1
 #define rb_rlim_t rlim_t
 #define SIGNEDNESS_OF_RLIM_T +1
 #define RLIM2NUM(v) ULL2NUM(v)
 #define NUM2RLIM(v) NUM2ULL(v)
 #define PRI_RLIM_PREFIX PRI_LL_PREFIX
+#define HAVE_OFF_T 1
 #define rb_off_t off_t
 #define SIGNEDNESS_OF_OFF_T -1
 #define OFFT2NUM(v) LL2NUM(v)
 #define NUM2OFFT(v) NUM2LL(v)
 #define PRI_OFFT_PREFIX PRI_LL_PREFIX
+#define HAVE_CLOCKID_T 1
 #define rb_clockid_t clockid_t
 #define SIGNEDNESS_OF_CLOCKID_T -1
 #define CLOCKID2NUM(v) INT2NUM(v)
@@ -117,6 +125,8 @@
 #define STRINGIZE(expr) STRINGIZE0(expr)
 #define HAVE_STDARG_PROTOTYPES 1
 #define HAVE_VA_ARGS_MACRO 1
+#define RUBY_ALIGNAS(x) __attribute__((__aligned__(x)))
+#define RUBY_ALIGNOF alignof
 #define CONSTFUNC(x) __attribute__ ((__const__)) x
 #define PUREFUNC(x) __attribute__ ((__pure__)) x
 #define NORETURN(x) __attribute__ ((__noreturn__)) x
@@ -125,6 +135,9 @@
 #define DEPRECATED_TYPE(mesg,x) x __attribute__ ((__deprecated__ mesg))
 #define NOINLINE(x) __attribute__ ((__noinline__)) x
 #define ALWAYS_INLINE(x) __attribute__ ((__always_inline__)) x
+#define NO_SANITIZE(san, x) __attribute__ ((__no_sanitize__(san))) x
+#define NO_SANITIZE_ADDRESS(x) __attribute__ ((__no_sanitize_address__)) x
+#define NO_ADDRESS_SAFETY_ANALYSIS(x) __attribute__ ((__no_address_safety_analysis__)) x
 #define WARN_UNUSED_RESULT(x) __attribute__ ((__warn_unused_result__)) x
 #define MAYBE_UNUSED(x) __attribute__ ((__unused__)) x
 #define WEAK(x) __attribute__ ((__weak__)) x
@@ -169,7 +182,6 @@
 #define SIZEOF_STRUCT_TIMEVAL_TV_SEC SIZEOF_TIME_T
 #define HAVE_STRUCT_TIMESPEC 1
 #define HAVE_STRUCT_TIMEZONE 1
-#define HAVE_CLOCKID_T 1
 #define HAVE_RB_FD_INIT 1
 #define HAVE_INT8_T 1
 #define SIZEOF_INT8_T 1
@@ -193,7 +205,7 @@
 #define SIZEOF_UINTPTR_T 4
 #define HAVE_SSIZE_T 1
 #define SIZEOF_SSIZE_T 4
-#define HEAP_PAGE_ALIGN_LOG 12
+#define PRI_64_PREFIX "ll"
 #define GETGROUPS_T gid_t
 #define RETSIGTYPE void
 #define HAVE_ALLOCA 1
@@ -211,6 +223,7 @@
 #define HAVE_ISNAN 1
 #define HAVE_LGAMMA_R 1
 #define HAVE_MEMMOVE 1
+#define HAVE_NAN 1
 #define HAVE_NEXTAFTER 1
 #define HAVE_SETPROCTITLE 1
 #define HAVE_STRCHR 1
@@ -263,6 +276,7 @@
 #define HAVE_GETSID 1
 #define HAVE_GETTIMEOFDAY 1
 #define HAVE_GMTIME_R 1
+#define HAVE_GRANTPT 1
 #define HAVE_INITGROUPS 1
 #define HAVE_IOCTL 1
 #define HAVE_ISSETUGID 1
@@ -322,6 +336,8 @@
 #define HAVE_UTIMES 1
 #define HAVE_WAIT4 1
 #define HAVE_WAITPID 1
+#define HAVE_BUILTIN___BUILTIN_ALLOCA_WITH_ALIGN 1
+#define HAVE_BUILTIN___BUILTIN_ASSUME_ALIGNED 1
 #define HAVE_BUILTIN___BUILTIN_BSWAP16 1
 #define HAVE_BUILTIN___BUILTIN_BSWAP32 1
 #define HAVE_BUILTIN___BUILTIN_BSWAP64 1
@@ -339,6 +355,7 @@
 #define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR 1
 #define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR_CONSTANT_P 1
 #define HAVE_BUILTIN___BUILTIN_TYPES_COMPATIBLE_P 1
+#define HAVE_BUILTIN___BUILTIN_TRAP 1
 #define ATAN2_INF_C99 1
 #define HAVE_CLOCK_GETRES 1
 #define HAVE_STRUCT_TM_TM_ZONE 1
@@ -358,11 +375,9 @@
 #define HAVE_SCHED_YIELD 1
 #define HAVE_PTHREAD_ATTR_SETINHERITSCHED 1
 #define HAVE_PTHREAD_ATTR_GETSTACK 1
-#define HAVE_PTHREAD_ATTR_INIT 1
+#define HAVE_PTHREAD_ATTR_GETGUARDSIZE 1
 #define HAVE_PTHREAD_STACKSEG_NP 1
-#define HAVE_PTHREAD_COND_INIT 1
 #define HAVE_PTHREAD_CONDATTR_SETCLOCK 1
-#define HAVE_PTHREAD_CONDATTR_INIT 1
 #define HAVE_PTHREAD_SIGMASK 1
 #define HAVE_PTHREAD_SET_NAME_NP 1
 #define SET_CURRENT_THREAD_NAME(name) pthread_set_name_np(pthread_self(), name)
@@ -380,6 +395,7 @@
 #define RUBY_SETJMP(env) __builtin_setjmp((void **)(env))
 #define RUBY_LONGJMP(env,val) __builtin_longjmp((void **)(env),val)
 #define RUBY_JMP_BUF jmp_buf
+#define USE_MJIT 1
 #define HAVE_PTHREAD_H 1
 #define RUBY_PLATFORM "i386-openbsd"
 #endif /* INCLUDE_RUBY_CONFIG_H */
