@@ -1,3 +1,4 @@
+# frozen_string_literal: false
 # = uri/ldap.rb
 #
 # Author::
@@ -6,25 +7,26 @@
 # License::
 #   URI::LDAP is copyrighted free software by Takaaki Tateishi and Akira Yamada.
 #   You can redistribute it and/or modify it under the same term as Ruby.
-# Revision:: $Id: ldap.rb 31555 2011-05-13 20:03:21Z drbrain $
+# Revision:: $Id: ldap.rb 65505 2018-11-02 17:52:33Z marcandre $
 #
 # See URI for general documentation
 #
 
-require 'uri/generic'
+require_relative 'generic'
 
 module URI
 
   #
-  # LDAP URI SCHEMA (described in RFC2255)
+  # LDAP URI SCHEMA (described in RFC2255).
+  #--
   # ldap://<host>/<dn>[?<attrs>[?<scope>[?<filter>[?<extensions>]]]]
-  #
+  #++
   class LDAP < Generic
 
-    # A Default port of 389 for URI::LDAP
+    # A Default port of 389 for URI::LDAP.
     DEFAULT_PORT = 389
 
-    # An Array of the available components for URI::LDAP
+    # An Array of the available components for URI::LDAP.
     COMPONENT = [
       :scheme,
       :host, :port,
@@ -39,8 +41,8 @@ module URI
     #
     # * SCOPE_BASE - the Base DN
     # * SCOPE_ONE  - one level under the Base DN, not including the base DN and
-    #                not including any entries under this.
-    # * SCOPE_SUB  - subtress, all entries at all levels
+    #   not including any entries under this
+    # * SCOPE_SUB  - subtrees, all entries at all levels
     #
     SCOPE = [
       SCOPE_ONE = 'one',
@@ -51,7 +53,7 @@ module URI
     #
     # == Description
     #
-    # Create a new URI::LDAP object from components, with syntax checking.
+    # Creates a new URI::LDAP object from components, with syntax checking.
     #
     # The components accepted are host, port, dn, attributes,
     # scope, filter, and extensions.
@@ -59,15 +61,15 @@ module URI
     # The components should be provided either as an Array, or as a Hash
     # with keys formed by preceding the component names with a colon.
     #
-    # If an Array is used, the components must be passed in the order
-    # [host, port, dn, attributes, scope, filter, extensions].
+    # If an Array is used, the components must be passed in the
+    # order <code>[host, port, dn, attributes, scope, filter, extensions]</code>.
     #
     # Example:
     #
-    #     newuri = URI::LDAP.build({:host => 'ldap.example.com',
-    #       :dn> => '/dc=example'})
+    #     uri = URI::LDAP.build({:host => 'ldap.example.com',
+    #       :dn => '/dc=example'})
     #
-    #     newuri = URI::LDAP.build(["ldap.example.com", nil,
+    #     uri = URI::LDAP.build(["ldap.example.com", nil,
     #       "/dc=example;dc=com", "query", nil, nil, nil])
     #
     def self.build(args)
@@ -91,19 +93,18 @@ module URI
     #
     # == Description
     #
-    # Create a new URI::LDAP object from generic URI components as per
+    # Creates a new URI::LDAP object from generic URI components as per
     # RFC 2396. No LDAP-specific syntax checking is performed.
     #
     # Arguments are +scheme+, +userinfo+, +host+, +port+, +registry+, +path+,
-    # +opaque+, +query+ and +fragment+, in that order.
+    # +opaque+, +query+, and +fragment+, in that order.
     #
     # Example:
     #
-    #     uri = URI::LDAP.new("ldap", nil, "ldap.example.com", nil,
-    #       "/dc=example;dc=com", "query", nil, nil, nil, nil)
+    #     uri = URI::LDAP.new("ldap", nil, "ldap.example.com", nil, nil,
+    #       "/dc=example;dc=com", nil, "query", nil)
     #
-    #
-    # See also URI::Generic.new
+    # See also URI::Generic.new.
     #
     def initialize(*arg)
       super(*arg)
@@ -116,14 +117,14 @@ module URI
       parse_query
     end
 
-    # private method to cleanup +dn+ from using the +path+ component attribute
+    # Private method to cleanup +dn+ from using the +path+ component attribute.
     def parse_dn
       @dn = @path[1..-1]
     end
     private :parse_dn
 
-    # private method to cleanup +attributes+, +scope+, +filter+ and +extensions+,
-    # from using the +query+ component attribute
+    # Private method to cleanup +attributes+, +scope+, +filter+, and +extensions+
+    # from using the +query+ component attribute.
     def parse_query
       @attributes = nil
       @scope      = nil
@@ -141,7 +142,7 @@ module URI
     end
     private :parse_query
 
-    # private method to assemble +query+ from +attributes+, +scope+, +filter+ and +extensions+.
+    # Private method to assemble +query+ from +attributes+, +scope+, +filter+, and +extensions+.
     def build_path_query
       @path = '/' + @dn
 
@@ -154,12 +155,12 @@ module URI
     end
     private :build_path_query
 
-    # returns dn.
+    # Returns dn.
     def dn
       @dn
     end
 
-    # private setter for dn +val+
+    # Private setter for dn +val+.
     def set_dn(val)
       @dn = val
       build_path_query
@@ -167,18 +168,18 @@ module URI
     end
     protected :set_dn
 
-    # setter for dn +val+
+    # Setter for dn +val+.
     def dn=(val)
       set_dn(val)
       val
     end
 
-    # returns attributes.
+    # Returns attributes.
     def attributes
       @attributes
     end
 
-    # private setter for attributes +val+
+    # Private setter for attributes +val+.
     def set_attributes(val)
       @attributes = val
       build_path_query
@@ -186,18 +187,18 @@ module URI
     end
     protected :set_attributes
 
-    # setter for attributes +val+
+    # Setter for attributes +val+.
     def attributes=(val)
       set_attributes(val)
       val
     end
 
-    # returns scope.
+    # Returns scope.
     def scope
       @scope
     end
 
-    # private setter for scope +val+
+    # Private setter for scope +val+.
     def set_scope(val)
       @scope = val
       build_path_query
@@ -205,18 +206,18 @@ module URI
     end
     protected :set_scope
 
-    # setter for scope +val+
+    # Setter for scope +val+.
     def scope=(val)
       set_scope(val)
       val
     end
 
-    # returns filter.
+    # Returns filter.
     def filter
       @filter
     end
 
-    # private setter for filter +val+
+    # Private setter for filter +val+.
     def set_filter(val)
       @filter = val
       build_path_query
@@ -224,18 +225,18 @@ module URI
     end
     protected :set_filter
 
-    # setter for filter +val+
+    # Setter for filter +val+.
     def filter=(val)
       set_filter(val)
       val
     end
 
-    # returns extensions.
+    # Returns extensions.
     def extensions
       @extensions
     end
 
-    # private setter for extensions +val+
+    # Private setter for extensions +val+.
     def set_extensions(val)
       @extensions = val
       build_path_query
@@ -243,14 +244,14 @@ module URI
     end
     protected :set_extensions
 
-    # setter for extensions +val+
+    # Setter for extensions +val+.
     def extensions=(val)
       set_extensions(val)
       val
     end
 
-    # Checks if URI has a path
-    # For URI::LDAP this will return +false+
+    # Checks if URI has a path.
+    # For URI::LDAP this will return +false+.
     def hierarchical?
       false
     end
